#!/usr/bin/env python

"""Tests for `file_provenance_utils` package."""


import unittest

from file_provenance_utils import file_provenance_utils


class TestFile_provenance_utils(unittest.TestCase):
    """Tests for `file_provenance_utils` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""



import logging
import os
import socket
import sys

from datetime import datetime


def get_provenance(**kwargs) -> str:
    """Retrieve provenance information to be inserted into plain text output file.

    This might be for a tab-delimited or comma-separated or plain text file.

    Args:
        **kwargs: Arbitrary keyword arguments.

    Returns:
        str: The provenance information.
    """
    logging.info(
        f"Will attempt to derive the provenance information to be inserted into a plain text file."
    )

    contents = []

    executable = kwargs.get("executable", os.path.abspath(sys.argv[0]))
    contents.append(f"executable: {executable}")

    config_file = kwargs.get("config_file", None)
    if config_file is not None:
        contents.append(f"config_file: {config_file}")

    logfile = kwargs.get("logfile", None)
    if logfile is not None:
        contents.append(f"logfile: {logfile}")

    date_created = kwargs.get("date-created", None)
    if date_created is None:
        date_created = datetime.today().strftime("%Y-%m-%d %H:%M:%S")
    contents.append(f"date-created: {date_created}")

    host = kwargs.get("host", socket.gethostname())
    contents.append(f"host: {host}")

    user = kwargs.get(
        "user", os.getenv("USER") or os.getenv("USERNAME") or "unknown-user"
    )
    contents.append(f"user: {user}")

    outdir = kwargs.get("outdir", None)
    if outdir is not None:
        contents.append(f"outdir: {outdir}")

    files = kwargs.get("files", None)
    if files is not None:
        contents.append("files:")
        # from pprint import pprint
        # pprint(files)
        # # sys.exit(1)
        for file_name, filepath in files.items():
            contents.append(f"{file_name}: {os.path.abspath(filepath)}")

    prefixed_contents = [f"## {content}" for content in contents]
    return "\n".join(prefixed_contents)



import logging
import os
import socket
import sys

from datetime import datetime

from typing import Any, Dict


def get_provenance(**kwargs) -> Dict[str, Any]:
    """Retrieve provenance information to be inserted into JSON output file.

    Args:
        **kwargs: Arbitrary keyword arguments.

    Returns:
        Dict[str, Any]: The provenance information.
    """
    logging.info(
        f"Will attempt to derive the provenance information to be inserted into a JSON file."
    )

    contents = {}

    executable = kwargs.get("executable", os.path.abspath(sys.argv[0]))
    contents["executable"] = executable

    config_file = kwargs.get("config_file", None)
    if config_file is not None:
        contents["config_file"] = config_file

    logfile = kwargs.get("logfile", None)
    if logfile is not None:
        contents["logfile"] = logfile

    date_created = kwargs.get("date-created", None)
    if date_created is None:
        date_created = datetime.today().strftime("%Y-%m-%d %H:%M:%S")

    contents["date-created"] = date_created

    host = kwargs.get("host", socket.gethostname())
    contents["host"] = host

    user = kwargs.get(
        "user", os.getenv("USER") or os.getenv("USERNAME") or "unknown-user"
    )
    contents["user"] = user

    outdir = kwargs.get("outdir", None)
    if outdir is not None:
        contents["outdir"] = outdir

    files = kwargs.get("files", None)
    if files is not None:
        contents["files"] = {}
        for file_name, filepath in files.items():
            contents["files"][file_name] = os.path.abspath(filepath)

    return {"provenance": contents}



import logging
import os
import socket
import sys

from datetime import datetime

import xml.etree.ElementTree as ET
from xml.dom import minidom


def get_provenance(**kwargs) -> str:
    """Retrieve provenance information to be inserted into XML output file.

    Args:
        **kwargs: Arbitrary keyword arguments.

    Returns:
        str: The provenance information in XML format.
    """
    logging.info(
        f"Will attempt to derive the provenance information to be inserted into an XML file."
    )

    # Create the root element for XML
    root = ET.Element("provenance")

    # Retrieve and set the executable
    executable = kwargs.get("executable", os.path.abspath(sys.argv[0]))
    executable_elem = ET.SubElement(root, "executable")
    executable_elem.text = executable

    # Retrieve and set the config file (if provided)
    config_file = kwargs.get("config_file", None)
    if config_file is not None:
        config_file_elem = ET.SubElement(root, "config_file")
        config_file_elem.text = config_file

    # Retrieve and set the logfile (if provided)
    logfile = kwargs.get("logfile", None)
    if logfile is not None:
        logfile_elem = ET.SubElement(root, "logfile")
        logfile_elem.text = logfile

    # Retrieve and set the datetime
    date_created = kwargs.get("date-created", None)
    if date_created is None:
        date_created = datetime.today().strftime("%Y-%m-%d %H:%M:%S")

    date_created_elem = ET.SubElement(root, "date-created")
    date_created_elem.text = date_created

    # Retrieve and set the host
    host = kwargs.get("host", socket.gethostname())
    host_elem = ET.SubElement(root, "host")
    host_elem.text = host

    # Retrieve and set the user
    user = kwargs.get(
        "user", os.getenv("USER") or os.getenv("USERNAME") or "unknown-user"
    )
    user_elem = ET.SubElement(root, "user")
    user_elem.text = user

    # Retrieve and set the output directory (if provided)
    outdir = kwargs.get("outdir", None)
    if outdir is not None:
        outdir_elem = ET.SubElement(root, "outdir")
        outdir_elem.text = outdir

    # Retrieve and set the files (if provided)
    files = kwargs.get("files", None)
    if files is not None:
        files_elem = ET.SubElement(root, "files")
        for file_name, filepath in files.items():
            file_elem = ET.SubElement(files_elem, "file")
            file_elem.set("name", file_name)
            file_elem.text = os.path.abspath(filepath)

    # # Generate the XML string
    # tree = ET.ElementTree(root)
    # from io import StringIO
    # xml_str = StringIO()
    # tree.write(xml_str, encoding="unicode", xml_declaration=True)
    # return xml_str.getvalue()

    # Generate the XML string
    tree = ET.ElementTree(root)
    from io import StringIO

    xml_str = StringIO()
    tree.write(xml_str, encoding="unicode", xml_declaration=True)

    # Parse the string and pretty print it
    xml_str.seek(0)
    pretty_xml = minidom.parseString(xml_str.getvalue()).toprettyxml(indent="    ")

    return pretty_xml



import logging
import os

from datetime import datetime

DEFAULT_PROJECT = "TBD"

DEFAULT_TIMESTAMP = str(datetime.today().strftime("%Y-%m-%d-%H%M%S"))

DEFAULT_OUTDIR = os.path.join(
    "/tmp/",
    os.getenv("USER"),
    DEFAULT_PROJECT,
    os.path.basename(__file__),
    DEFAULT_TIMESTAMP,
)

DEFAULT_LOGGING_FORMAT = (
    "%(levelname)s : %(asctime)s : %(pathname)s : %(lineno)d : %(message)s"
)

DEFAULT_LOGGING_LEVEL = logging.INFO

DEFAULT_VERBOSE = False



"""Top-level package for File Provenance Utils."""

__author__ = """Jaideep Sundaram"""
__email__ = "jai.python3@gmail.com"
__version__ = "0.1.0"

from file_provenance_utils.plain_text_util import (
    get_provenance as get_plain_text_provenance,
)
from file_provenance_utils.json_util import get_provenance as get_json_provenance
from file_provenance_utils.xml_util import get_provenance as get_xml_provenance



#!/usr/bin/env python
"""The setup script."""
import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), "README.md")) as readme_fh:
    readme = readme_fh.read()

with open("HISTORY.rst") as changelog_fh:
    changelog = changelog_fh.read()

requirements = ["Click>=7.0", "PyYAML", "Rich"]

test_requirements = []

setup(
    author="Jaideep Sundaram",
    author_email="jai.python3@gmail.com",
    python_requires=">=3.10",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.10",
    ],
    description="Collection of functions for inserting provenance information to the output files.",
    entry_points={
        "console_scripts": [
            "run-queries=file_provenance_utils.run_queries:main",
        ],
    },
    install_requires=requirements,
    long_description=readme + "\n\n" + changelog,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords="file_provenance_utils",
    name="file_provenance_utils",
    packages=find_packages(
        include=["file_provenance_utils", "file_provenance_utils.*"]
    ),
    package_data={
        "file_provenance_utils": [
            "conf/config.yaml",
        ]
    },
    # scripts=["scripts/make_executables_and_aliases.py"],
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/jai-python3/file-provenance-utils",
    version="0.1.1",
    zip_safe=False,
)
